@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2016 Codership Oy <info@codership.com>
+ * Copyright (C) 2009-2015 Codership Oy <info@codership.com>
  *
  * $Id$
  */
@@ -37,15 +37,11 @@ namespace gu
     static int const OPEN_FLAGS   = O_RDWR | O_NOATIME | O_CLOEXEC;
     static int const CREATE_FLAGS = OPEN_FLAGS | O_CREAT /*| O_TRUNC*/;
 
-    /* respect user umask by allowing all bits by default */
-    static mode_t const CREATE_MODE =
-        S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH ;
-
     FileDescriptor::FileDescriptor (const std::string& fname,
-                                    bool const         sync)
+                                    bool const          sync)
         : name_(fname),
-          fd_  (open (name_.c_str(), OPEN_FLAGS)),
-          size_(fd_ < 0 ? 0 : lseek (fd_, 0, SEEK_END)),
+          fd_  (open (name_.c_str(), OPEN_FLAGS, S_IRUSR | S_IWUSR)),
+          size_(lseek (fd_, 0, SEEK_END)),
           sync_(sync)
     {
         constructor_common();
@@ -60,7 +56,8 @@ namespace gu
 
         if (0 == err)
         {
-            unsigned long long  const free_size(stat.f_bavail * stat.f_bsize);
+            unsigned long long free_size = stat.f_bavail;
+            free_size *= stat.f_bsize;
 
             if (reserve < free_size)
             {
@@ -85,7 +82,7 @@ namespace gu
                                     bool   const       allocate,
                                     bool   const       sync)
         : name_(fname),
-          fd_  (open (fname.c_str(), CREATE_FLAGS, CREATE_MODE)),
+          fd_  (open (fname.c_str(), CREATE_FLAGS, S_IRUSR | S_IWUSR)),
           size_(size),
           sync_(sync)
     {
@@ -124,7 +121,7 @@ namespace gu
 
             if (ftruncate(fd_, size_))
             {
-                gu_throw_system_error(errno) << "Failed to truncate '" << name_
+                gu_throw_error(errno) << "Failed to truncate '" << name_
                                       << "' to " << size_ << " bytes.";
             }
         }
@@ -138,8 +135,7 @@ namespace gu
     FileDescriptor::constructor_common()
     {
         if (fd_ < 0) {
-            gu_throw_system_error(errno)
-                << "Failed to open file '" + name_ + '\'';
+            gu_throw_error(errno) << "Failed to open file '" + name_ + '\'';
         }
 #if !defined(__APPLE__) /* Darwin does not have posix_fadvise */
 /* benefits are questionable
@@ -158,9 +154,11 @@ namespace gu
 
     FileDescriptor::~FileDescriptor ()
     {
-        if (sync_)
+        if (sync_ && fsync(fd_) != 0)
         {
-            try { sync(); } catch (Exception& e) { log_error << e.what(); }
+            int const err(errno);
+            log_error << "Failed to flush file '" << name_ << "': "
+                      << err << " (" << strerror(err) << '\'';
         }
 
         if (close(fd_) != 0)
@@ -176,12 +174,12 @@ namespace gu
     }
 
     void
-    FileDescriptor::sync () const
+    FileDescriptor::flush () const
     {
         log_debug << "Flushing file '" << name_ << "'";
 
         if (fsync (fd_) < 0) {
-            gu_throw_system_error(errno) << "fsync() failed on '" + name_ + '\'';
+            gu_throw_error(errno) << "fsync() failed on '" + name_ + '\'';
         }
 
         log_debug << "Flushed file '" << name_ << "'";
@@ -193,12 +191,10 @@ namespace gu
         byte_t const byte (0);
 
         if (lseek (fd_, offset, SEEK_SET) != offset)
-            gu_throw_system_error(errno)
-                << "lseek() failed on '" << name_ << '\'';
+            gu_throw_error(errno) << "lseek() failed on '" << name_ << '\'';
 
         if (write (fd_, &byte, sizeof(byte)) != sizeof(byte))
-            gu_throw_system_error(errno)
-                << "write() failed on '" << name_ << '\'';
+            gu_throw_error(errno) << "write() failed on '" << name_ << '\'';
 
         return true;
     }
@@ -218,13 +214,12 @@ namespace gu
             offset += GU_PAGE_SIZE;
         }
 
-        if (offset >= size_ && write_byte (size_ - 1))
+        if (offset >= size_ && write_byte (size_ - 1) && fsync (fd_) == 0)
         {
-            sync();
             return;
         }
 
-        gu_throw_system_error (errno) << "File preallocation failed";
+        gu_throw_error (errno) << "File preallocation failed";
     }
 
     void
@@ -236,14 +231,11 @@ namespace gu
                   << name_ << "'...";
 
 #if defined(__APPLE__)
-        if (-1 == fcntl (fd_, F_SETSIZE, size_) && -1 == ftruncate (fd_, size_))
-        {
+        if (0 != fcntl (fd_, F_SETSIZE, size_) && 0 != ftruncate (fd_, size_))
 #else
-        int const ret = posix_fallocate (fd_, start, diff);
-        if (0 != ret)
-        {
-            errno = ret;
+        if (0 != posix_fallocate (fd_, start, diff))
 #endif
+        {
             if ((EINVAL == errno || ENOSYS == errno) && start >= 0 && diff > 0)
             {
                 // FS does not support the operation, try physical write
@@ -251,7 +243,7 @@ namespace gu
             }
             else
             {
-                gu_throw_system_error (errno) << "File preallocation failed";
+                gu_throw_error (errno) << "File preallocation failed";
             }
         }
     }
